==> 1.0.0.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/flutter/handler/FWSdkModuleHandler.kt <==
package com.fireworksdk.bridge.flutter.handler

import android.annotation.SuppressLint
import android.content.Context
import android.content.pm.PackageManager
import android.provider.Settings
import com.fireworksdk.bridge.flutter.models.FWSdkInitModel
import com.fireworksdk.bridge.flutter.models.FWSdkModuleCallMethod
import com.fireworksdk.bridge.flutter.utils.FWEventUtils
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.utils.FWJsonUtils
import com.fireworksdk.bridge.utils.FWLogUtils
import com.fireworksdk.bridge.utils.FWUrlUtils
import com.fireworksdk.bridge.utils.FWVideoPlayerUtils
import com.loopnow.fireworklibrary.FwSDK
import com.loopnow.fireworklibrary.SdkStatus
import com.loopnow.fireworklibrary.VideoEvent
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import org.json.JSONObject


class FWSdkModuleHandler(
    private val context: Context,
    channel: MethodChannel?
): MethodCallHandler {

    private var handleResult: Result? = null
    private val methodChannel by weakProperty<MethodChannel?>(channel)

    override fun onMethodCall(call: MethodCall, result: Result) {
        handleResult = result
        when (call.method) {
            FWSdkModuleCallMethod.Init.rawValue -> {
                val map: HashMap<String, Any> = call.arguments as HashMap<String, Any>
                val data = FWJsonUtils.fromJson(FWJsonUtils.toJson(map), FWSdkInitModel::class.java)
                init(data?.userId)
                result.success(null)
            }
            FWSdkModuleCallMethod.OpenVideoPlayer.rawValue -> {
                val map: HashMap<String, Any> = call.arguments as HashMap<String, Any>
                if (map.size > 0) {
                    val url = map["url"] as String
                    val config = map["config"] as HashMap<String, Any?>?
                    openVideoPlayer(url, config)
                }
                result.success(null)
            }
            FWSdkModuleCallMethod.SetCustomCTAClickEnabled.rawValue -> {
                val value: Boolean? = call.arguments as Boolean?
                FWVideoPlayerUtils.customCTAClickEnabled = value?:false
                handleCustomCTAClick()
                result.success(null)
            }
            FWSdkModuleCallMethod.SetVideoPlaybackEventEnabled.rawValue -> {
                val value: Boolean? = call.arguments as Boolean?
                FWVideoPlayerUtils.videoPlaybackEventEnabled = value?:false
                handleVideoPlaybackEvent()
                result.success(null)
            }
            FWSdkModuleCallMethod.SetShareBaseURL.rawValue -> {
                val url: String? = call.arguments as String?
                setShareBaseURL(url)
                result.success(null)
            }
            FWSdkModuleCallMethod.setAdBadgeConfiguration.rawValue -> {
                val map: HashMap<String, Any> = call.arguments as HashMap<String, Any>
                val data = FWJsonUtils.fromJson(FWJsonUtils.toJson(map), FWAdBadgeConfigModel::class.java)
                FWVideoPlayerUtils.setAdBadgeConfig(data)
                result.success(null)
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    private fun init(userId: String?) {
        val clientId = getAppid()
        if (clientId.isNullOrBlank()) {
            val errorMsg = "The appid is invalid"
            FWLogUtils.e { errorMsg }
            FWEventUtils.sendInitFailedEvent(methodChannel, errorMsg)
            return
        }
        val uid = if (userId.isNullOrBlank()) { getHashedAndroidId() } else userId

        FwSDK.initialize(
            context,
            clientId,
            uid,
            object : FwSDK.SdkStatusListener {
                override fun currentStatus(status: SdkStatus, extra: String) {
                    when (status) {
                        SdkStatus.Initialized -> {
                            FWEventUtils.sendInitSuccessEvent(methodChannel)
                        }
                        SdkStatus.InitializationFailed -> {
                            FWEventUtils.sendInitFailedEvent(methodChannel, extra)
                        }
                        SdkStatus.RefreshTokenFailed -> {
                            FWEventUtils.sendInitFailedEvent(methodChannel, extra)
                        }
                    }
                }
            })
    }

    private fun getAppid(): String? {
        val ai = context.packageManager.getApplicationInfo(
            context.packageName,
            PackageManager.GET_META_DATA
        )
        val value = ai.metaData.get("Firework:Appid")
        return value?.let {
            it as String
        } ?: run {
            null
        }
    }

    @SuppressLint("HardwareIds")
    private fun getHashedAndroidId(): String {
        val androidId = Settings.Secure.getString(
            context.contentResolver,
            Settings.Secure.ANDROID_ID
        )
        return FwSDK.getHash(androidId)
    }



    private fun handleCustomCTAClick() {
        if (!FWVideoPlayerUtils.customCTAClickEnabled) {
            return
        }
        FwSDK.ctaClickHandler = object: FwSDK.CtaClickHandler {
            override fun ctaClicked(label: String, actionUrl: String?): Boolean {
                FWLogUtils.d { "ctaClicked" }
                FWEventUtils.sendCustomCTAClickEvent(methodChannel, actionUrl)
                return FWVideoPlayerUtils.customCTAClickEnabled
            }
        }
    }

    private fun setShareBaseURL(url: String?) {
        if (!url.isNullOrBlank()) {
            FwSDK.setBasePlayerUrl(url)
        }
    }

    private fun handleVideoPlaybackEvent() {
        if (!FWVideoPlayerUtils.videoPlaybackEventEnabled) {
            return
        }
        FwSDK.addVideoEventListener(object: FwSDK.VideoEventListener {
            override fun event(event: String, jsonObject: JSONObject) {
                val videoPlaybackDetails = FWJsonUtils.fromJson(jsonObject.toString(), FWVideoPlaybackDetails::class.java)

                when (event) {
                    VideoEvent.videoImpression -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Impression.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoStart -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Start.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoFirstQuartile -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.FirstQuartile.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoMidpoint -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Midpoint.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoThirdQuartile -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.ThirdQuartile.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoComplete -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Complete.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoSession -> {

                    }
                    VideoEvent.videoAdStart -> {

                    }
                    VideoEvent.videoAdEnd -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.AdEnd.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoClickCta -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.ClickCTA.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoShare -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.ClickShare.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoStartError -> {

                    }
                    VideoEvent.videoAdStartError -> {

                    }
                }
            }
        })
    }

    private fun openVideoPlayer(url: String, configMap: HashMap<String, Any?>?) {
        val encodedParameters = FWUrlUtils.queryParamString(url, "fwplayer")
        if (encodedParameters.isNullOrBlank()) {
            FWLogUtils.e { "The parameter url is invalid: $url" }
            return
        }

        // set configuration
        val videoPlayerContentConfigModel = FWJsonUtils.fromMap(configMap, FWVideoPlayerConfigModel::class.java)
        FWVideoPlayerUtils.setVideoPlayerConfig(videoPlayerContentConfigModel)

        // open player
        FwSDK.play(encodedParameters)
    }

}

==> 1.1.1.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/flutter/handler/FWSdkModuleHandler.kt <==
package com.fireworksdk.bridge.flutter.handler

import android.annotation.SuppressLint
import android.content.Context
import android.content.pm.PackageManager
import android.provider.Settings
import com.fireworksdk.bridge.flutter.models.FWSdkInitModel
import com.fireworksdk.bridge.flutter.models.FWSdkModuleCallMethod
import com.fireworksdk.bridge.flutter.utils.FWEventUtils
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.utils.FWJsonUtils
import com.fireworksdk.bridge.utils.FWLogUtils
import com.fireworksdk.bridge.utils.FWUrlUtils
import com.fireworksdk.bridge.utils.FWVideoPlayerUtils
import com.loopnow.fireworklibrary.FwSDK
import com.loopnow.fireworklibrary.SdkStatus
import com.loopnow.fireworklibrary.VideoEvent
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import org.json.JSONObject


class FWSdkModuleHandler(
    private val context: Context,
    channel: MethodChannel?
): MethodCallHandler {

    private var handleResult: Result? = null
    private val methodChannel by weakProperty<MethodChannel?>(channel)

    override fun onMethodCall(call: MethodCall, result: Result) {
        handleResult = result
        when (call.method) {
            FWSdkModuleCallMethod.Init.rawValue -> {
                val map: HashMap<String, Any> = call.arguments as HashMap<String, Any>
                val data = FWJsonUtils.fromJson(FWJsonUtils.toJson(map), FWSdkInitModel::class.java)
                init(data?.userId)
                result.success(null)
            }
            FWSdkModuleCallMethod.OpenVideoPlayer.rawValue -> {
                val map: HashMap<String, Any> = call.arguments as HashMap<String, Any>
                if (map.size > 0) {
                    val url = map["url"] as String
                    val config = map["config"] as HashMap<String, Any?>?
                    openVideoPlayer(url, config)
                }
                result.success(null)
            }
            FWSdkModuleCallMethod.SetCustomCTAClickEnabled.rawValue -> {
                val value: Boolean? = call.arguments as Boolean?
                FWVideoPlayerUtils.customCTAClickEnabled = value?:false
                handleCustomCTAClick()
                result.success(null)
            }
            FWSdkModuleCallMethod.SetVideoPlaybackEventEnabled.rawValue -> {
                val value: Boolean? = call.arguments as Boolean?
                FWVideoPlayerUtils.videoPlaybackEventEnabled = value?:false
                handleVideoPlaybackEvent()
                result.success(null)
            }
            FWSdkModuleCallMethod.SetShareBaseURL.rawValue -> {
                val url: String? = call.arguments as String?
                setShareBaseURL(url)
                result.success(null)
            }
            FWSdkModuleCallMethod.SetAdBadgeConfiguration.rawValue -> {
                val map: HashMap<String, Any> = call.arguments as HashMap<String, Any>
                val data = FWJsonUtils.fromJson(FWJsonUtils.toJson(map), FWAdBadgeConfigModel::class.java)
                FWVideoPlayerUtils.setAdBadgeConfig(data)
                result.success(null)
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    private fun init(userId: String?) {
        val clientId = getAppid()
        if (clientId.isNullOrBlank()) {
            val errorMsg = "The appid is invalid"
            FWLogUtils.e { errorMsg }
            FWEventUtils.sendInitFailedEvent(methodChannel, errorMsg)
            return
        }
        val uid = if (userId.isNullOrBlank()) { getHashedAndroidId() } else userId

        FwSDK.initialize(
            context,
            clientId,
            uid,
            object : FwSDK.SdkStatusListener {
                override fun currentStatus(status: SdkStatus, extra: String) {
                    when (status) {
                        SdkStatus.Initialized -> {
                            FWEventUtils.sendInitSuccessEvent(methodChannel)
                        }
                        SdkStatus.InitializationFailed -> {
                            FWEventUtils.sendInitFailedEvent(methodChannel, extra)
                        }
                        SdkStatus.RefreshTokenFailed -> {
                            FWEventUtils.sendInitFailedEvent(methodChannel, extra)
                        }
                    }
                }
            })
    }

    private fun getAppid(): String? {
        val ai = context.packageManager.getApplicationInfo(
            context.packageName,
            PackageManager.GET_META_DATA
        )
        val value = ai.metaData.get("Firework:Appid")
        return value?.let {
            it as String
        } ?: run {
            null
        }
    }

    @SuppressLint("HardwareIds")
    private fun getHashedAndroidId(): String {
        val androidId = Settings.Secure.getString(
            context.contentResolver,
            Settings.Secure.ANDROID_ID
        )
        return FwSDK.getHash(androidId)
    }

    private fun handleCustomCTAClick() {
        FwSDK.ctaClickHandler = object: FwSDK.CtaClickHandler {
            override fun ctaClicked(label: String, actionUrl: String?): Boolean {
                FWLogUtils.d { "ctaClicked" }
                FWEventUtils.sendCustomCTAClickEvent(methodChannel, actionUrl)
                return FWVideoPlayerUtils.customCTAClickEnabled
            }
        }
    }

    private fun setShareBaseURL(url: String?) {
        if (!url.isNullOrBlank()) {
            FwSDK.setBasePlayerUrl(url)
        }
    }

    private fun handleVideoPlaybackEvent() {
        if (!FWVideoPlayerUtils.videoPlaybackEventEnabled) {
            return
        }
        FwSDK.addVideoEventListener(object: FwSDK.VideoEventListener {
            override fun event(event: String, jsonObject: JSONObject) {
                val videoPlaybackDetails = FWJsonUtils.fromJson(jsonObject.toString(), FWVideoPlaybackDetails::class.java)

                when (event) {
                    VideoEvent.videoImpression -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Impression.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoStart -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Start.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoFirstQuartile -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.FirstQuartile.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoMidpoint -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Midpoint.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoThirdQuartile -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.ThirdQuartile.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoComplete -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.Complete.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoSession -> {

                    }
                    VideoEvent.videoAdStart -> {

                    }
                    VideoEvent.videoAdEnd -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.AdEnd.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoClickCta -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.ClickCTA.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoShare -> {
                        FWEventUtils.sendVideoPlaybackEvent(methodChannel, FWVideoPlaybackSubEventName.ClickShare.rawValue, videoPlaybackDetails)
                    }
                    VideoEvent.videoStartError -> {

                    }
                    VideoEvent.videoAdStartError -> {

                    }
                }
            }
        })
    }

    private fun openVideoPlayer(url: String, configMap: HashMap<String, Any?>?) {
        val encodedParameters = FWUrlUtils.queryParamString(url, "fwplayer")
        if (encodedParameters.isNullOrBlank()) {
            FWLogUtils.e { "The parameter url is invalid: $url" }
            return
        }

        // set configuration
        val videoPlayerContentConfigModel = FWJsonUtils.fromMap(configMap, FWVideoPlayerConfigModel::class.java)
        FWVideoPlayerUtils.setVideoPlayerConfig(videoPlayerContentConfigModel)

        // open player
        FwSDK.play(encodedParameters)
    }

}
